@@ -598,15 +598,15 @@ c-------------------------------------------------------------------------
 
 c-----------------------------------------------------------------------
 
-      subroutine compmu(r,ldr,n,mu,y)
+      subroutine compmu(r,ldr,n,mu,y,ierr)
 
-      integer ldr,n
+      integer ldr,n,ierr
       double precision r(ldr,*),mu,y(*)
 
 c-------------------------------------------------------------------------
 c
 c     Compute a small perturbation mu for the (almost) singular matrix R.
-c     mu is used in the computation of the levenberg-marquardt step.
+c     mu is used in the computation of the Levenberg-Marquardt step.
 c
 c     Arguments
 c
@@ -617,10 +617,12 @@ c     Out      mu      Real            sqrt(l1 norm of R * infinity norm of R
 c                                      * n * epsm * 100) designed to make
 c                                        trans(R)*R + mu * I not singular
 c     Wk       y       Real(*)         workspace for dlange
+c     Out      ierr    Integer         0 indicating mu ok
+c                                      3 indicating mu much too small
 c
 c-------------------------------------------------------------------------
 
-      double precision  aifnrm,al1nrm,epsm
+      double precision aifnrm,al1nrm,epsm
       double precision dlantr
       double precision epsmch
 
@@ -629,20 +631,21 @@ c-------------------------------------------------------------------------
 
 c     get the infinity norm of R
 c     get the l1 norm of R
-
+      ierr = 0
       aifnrm = dlantr('I','U','N',n,n,r,ldr,y)
       al1nrm = dlantr('1','U','N',n,n,r,ldr,y)
-
-c     compute mu
       epsm = epsmch()
       mu = sqrt(n*epsm*Rhund)*aifnrm*al1nrm
-
+c     matrix consists of zero's or near zero's
+c     LM correction in liqrev will not work
+      if( mu .le. Rhund*epsm ) then
+         ierr = 3
+      endif
       return
       end
 
 c-----------------------------------------------------------------------
 
-
       subroutine cndjac(n,r,ldr,cndtol,rcond,rcdwrk,icdwrk,ierr)
       integer n,ldr,icdwrk(*),ierr
       double precision cndtol,rcond,r(ldr,*),rcdwrk(*)
